summaryrefslogtreecommitdiff
path: root/nuttx/arch/arm/src/lpc31xx
diff options
context:
space:
mode:
authorGregory Nutt <gnutt@nuttx.org>2014-08-31 16:15:11 -0600
committerGregory Nutt <gnutt@nuttx.org>2014-08-31 16:15:11 -0600
commitfafba1669d8d4e158fc73442fde971670caf17dd (patch)
tree720999b8c8bf701ded85d2d5400196d04684aa86 /nuttx/arch/arm/src/lpc31xx
parent81baf55fd8f4e860516cdfbaa5db2d74b5289bfd (diff)
downloadnuttx-fafba1669d8d4e158fc73442fde971670caf17dd.tar.gz
nuttx-fafba1669d8d4e158fc73442fde971670caf17dd.tar.bz2
nuttx-fafba1669d8d4e158fc73442fde971670caf17dd.zip
Rename kufree to kumm_free for consistency with other naming
Diffstat (limited to 'nuttx/arch/arm/src/lpc31xx')
-rwxr-xr-xnuttx/arch/arm/src/lpc31xx/lpc31_ehci.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/nuttx/arch/arm/src/lpc31xx/lpc31_ehci.c b/nuttx/arch/arm/src/lpc31xx/lpc31_ehci.c
index bbac7edfa..2af7e0c13 100755
--- a/nuttx/arch/arm/src/lpc31xx/lpc31_ehci.c
+++ b/nuttx/arch/arm/src/lpc31xx/lpc31_ehci.c
@@ -3813,7 +3813,7 @@ static int lpc31_ioalloc(FAR struct usbhost_driver_s *drvr, FAR uint8_t **buffer
* Some hardware supports special memory in which IO data can be accessed more
* efficiently. This method provides a mechanism to free that IO buffer
* memory. If the underlying hardware does not support such "special" memory,
* this functions may simply map to kufree().
*
* Input Parameters:
* drvr - The USB host driver instance obtained as a parameter from the call to
@@ -3835,7 +3835,7 @@ static int lpc31_iofree(FAR struct usbhost_driver_s *drvr, FAR uint8_t *buffer)
/* No special action is require to free the I/O buffer memory */
- kufree(buffer);
+ kumm_free(buffer);
return OK;
}
@@ -3813,7 +3813,7 @@ static int lpc31_ioalloc(FAR struct usbhost_driver_s *drvr, FAR uint8_t **buffer
* efficiently. This method provides a mechanism to free that IO buffer
* memory. If the underlying hardware does not support such "special" memory,
- * this functions may simply map to kufree().
+ * this functions may simply map to kumm_free().
*
* Input Parameters: